==> haskell-quickcheck-io-0.2.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-io
version: 0.2.0
id: quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
key: quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
license: MIT
copyright: (c) 2013-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/quickcheck-io#readme
synopsis: Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.
category: Testing
abi: 391db9bfefe77ce03304f14e4733dc3c
exposed: True
exposed-modules:
    Test.QuickCheck.IO
hidden-modules: Paths_quickcheck_io
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-io-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/quickcheck-io-0.2.0
hs-libraries: HSquickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-io-0.2.0-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-io
version: 0.2.0
id: quickcheck-io-0.2.0-K1CixCxBGnbAXXJEyFVI3w
key: quickcheck-io-0.2.0-K1CixCxBGnbAXXJEyFVI3w
license: MIT
copyright: (c) 2013-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/quickcheck-io#readme
synopsis: Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.
category: Testing
abi: f4b2e0e427f08be1317499642468d47e
exposed: True
exposed-modules:
    Test.QuickCheck.IO
hidden-modules: Paths_quickcheck_io
import-dirs: /usr/lib/ghc-8.6.1/site-local/quickcheck-io-0.2.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/quickcheck-io-0.2.0
hs-libraries: HSquickcheck-io-0.2.0-K1CixCxBGnbAXXJEyFVI3w
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
